# synctera-client-v1
<h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.41.3
- Package version: 1.41.3
- Build package: org.openapitools.codegen.languages.PythonNextgenClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/SwadeshInc/synctera-client.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/SwadeshInc/synctera-client.git`)

Then import the package:
```python
import synctera_client_v1
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import synctera_client_v1
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import synctera_client_v1
from synctera_client_v1.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.synctera.com/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = synctera_client_v1.Configuration(
    host = "https://api.synctera.com/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (api_key): bearerAuth
configuration = synctera_client_v1.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with synctera_client_v1.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = synctera_client_v1.ApplicationsBetaApi(api_client)
    application = synctera_client_v1.Application() # Application | Application model.

    try:
        # Create an application
        api_response = api_instance.create_application(application)
        print("The response of ApplicationsBetaApi->create_application:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ApplicationsBetaApi->create_application: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.synctera.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApplicationsBetaApi* | [**create_application**](docs/ApplicationsBetaApi.md#create_application) | **POST** /applications | Create an application
*ApplicationsBetaApi* | [**get_application**](docs/ApplicationsBetaApi.md#get_application) | **GET** /applications/{application_id} | Get an application
*ApplicationsBetaApi* | [**list_applications**](docs/ApplicationsBetaApi.md#list_applications) | **GET** /applications | List applications
*ApplicationsBetaApi* | [**patch_application**](docs/ApplicationsBetaApi.md#patch_application) | **PATCH** /applications/{application_id} | Modify an application
*CardTransactionSimulationsBetaApi* | [**simulate_authorization**](docs/CardTransactionSimulationsBetaApi.md#simulate_authorization) | **POST** /cards/transaction_simulations/authorization | Simulate authorization
*CardTransactionSimulationsBetaApi* | [**simulate_authorization_advice**](docs/CardTransactionSimulationsBetaApi.md#simulate_authorization_advice) | **POST** /cards/transaction_simulations/authorization/advice | Simulate authorization advice
*CardTransactionSimulationsBetaApi* | [**simulate_balance_inquiry**](docs/CardTransactionSimulationsBetaApi.md#simulate_balance_inquiry) | **POST** /cards/transaction_simulations/financial/balance_inquiry | Simulate balance inquiry
*CardTransactionSimulationsBetaApi* | [**simulate_clearing**](docs/CardTransactionSimulationsBetaApi.md#simulate_clearing) | **POST** /cards/transaction_simulations/clearing | Simulate clearing or refund
*CardTransactionSimulationsBetaApi* | [**simulate_financial**](docs/CardTransactionSimulationsBetaApi.md#simulate_financial) | **POST** /cards/transaction_simulations/financial | Simulate financial
*CardTransactionSimulationsBetaApi* | [**simulate_financial_advice**](docs/CardTransactionSimulationsBetaApi.md#simulate_financial_advice) | **POST** /cards/transaction_simulations/financial/advice | Simulate financial advice
*CardTransactionSimulationsBetaApi* | [**simulate_original_credit**](docs/CardTransactionSimulationsBetaApi.md#simulate_original_credit) | **POST** /cards/transaction_simulations/financial/original_credit | Simulate OCT
*CardTransactionSimulationsBetaApi* | [**simulate_reversal**](docs/CardTransactionSimulationsBetaApi.md#simulate_reversal) | **POST** /cards/transaction_simulations/reversal | Simulate reversal
*CardTransactionSimulationsBetaApi* | [**simulate_withdrawal**](docs/CardTransactionSimulationsBetaApi.md#simulate_withdrawal) | **POST** /cards/transaction_simulations/financial/withdrawal | Simulate ATM withdrawal
*CardWebhookSimulationsBetaApi* | [**simulate_card_fulfillment_event**](docs/CardWebhookSimulationsBetaApi.md#simulate_card_fulfillment_event) | **POST** /cards/{card_id}/webhook_simulations/fulfillment | Simulate Card Fulfillment Event
*CardsBetaApi* | [**activate_card**](docs/CardsBetaApi.md#activate_card) | **POST** /cards/activate | Activate a card
*CardsBetaApi* | [**create_card_image**](docs/CardsBetaApi.md#create_card_image) | **POST** /cards/images | Create Card Image
*CardsBetaApi* | [**create_gateway**](docs/CardsBetaApi.md#create_gateway) | **POST** /cards/gateways | Create Gateway
*CardsBetaApi* | [**get_card**](docs/CardsBetaApi.md#get_card) | **GET** /cards/{card_id} | Get Card
*CardsBetaApi* | [**get_card_barcode**](docs/CardsBetaApi.md#get_card_barcode) | **GET** /cards/{card_id}/barcodes | Get Card Barcode
*CardsBetaApi* | [**get_card_image_data**](docs/CardsBetaApi.md#get_card_image_data) | **GET** /cards/images/{card_image_id}/data | Get Card Image Data
*CardsBetaApi* | [**get_card_image_details**](docs/CardsBetaApi.md#get_card_image_details) | **GET** /cards/images/{card_image_id} | Get Card Image Details
*CardsBetaApi* | [**get_card_widget_url**](docs/CardsBetaApi.md#get_card_widget_url) | **GET** /cards/card_widget_url | Get card widget URL
*CardsBetaApi* | [**get_client_access_token**](docs/CardsBetaApi.md#get_client_access_token) | **POST** /cards/{card_id}/client_token | Get a client token
*CardsBetaApi* | [**get_gateway**](docs/CardsBetaApi.md#get_gateway) | **GET** /cards/gateways/{gateway_id} | Get Gateway
*CardsBetaApi* | [**issue_card**](docs/CardsBetaApi.md#issue_card) | **POST** /cards | Issue a Card
*CardsBetaApi* | [**list_card_image_details**](docs/CardsBetaApi.md#list_card_image_details) | **GET** /cards/images | List Card Image Details
*CardsBetaApi* | [**list_card_products**](docs/CardsBetaApi.md#list_card_products) | **GET** /cards/products | List Card Products
*CardsBetaApi* | [**list_cards**](docs/CardsBetaApi.md#list_cards) | **GET** /cards | List Cards
*CardsBetaApi* | [**list_changes**](docs/CardsBetaApi.md#list_changes) | **GET** /cards/{card_id}/changes | List Card Changes
*CardsBetaApi* | [**list_gateways**](docs/CardsBetaApi.md#list_gateways) | **GET** /cards/gateways | List Gateways
*CardsBetaApi* | [**update_card**](docs/CardsBetaApi.md#update_card) | **PATCH** /cards/{card_id} | Update Card
*CardsBetaApi* | [**update_card_image_details**](docs/CardsBetaApi.md#update_card_image_details) | **PATCH** /cards/images/{card_image_id} | Update Card Image Details
*CardsBetaApi* | [**update_gateway**](docs/CardsBetaApi.md#update_gateway) | **PATCH** /cards/gateways/{gateway_id} | Update Gateway
*CardsBetaApi* | [**upload_card_image_data**](docs/CardsBetaApi.md#upload_card_image_data) | **POST** /cards/images/{card_image_id}/data | Upload Card Image
*DigitalWalletTokensBetaApi* | [**create_digital_wallet_apple**](docs/DigitalWalletTokensBetaApi.md#create_digital_wallet_apple) | **POST** /cards/{card_id}/digital_wallet_tokens/applepay | Create digital wallet token provision request for Apple Pay
*DigitalWalletTokensBetaApi* | [**create_digital_wallet_google**](docs/DigitalWalletTokensBetaApi.md#create_digital_wallet_google) | **POST** /cards/{card_id}/digital_wallet_tokens/googlepay | Create digital wallet token provision request for Google Pay
*DigitalWalletTokensBetaApi* | [**get_digital_wallet_token**](docs/DigitalWalletTokensBetaApi.md#get_digital_wallet_token) | **GET** /cards/digital_wallet_tokens/{digital_wallet_token_id} | Get Digital Wallet Token
*DigitalWalletTokensBetaApi* | [**list_digital_wallet_tokens**](docs/DigitalWalletTokensBetaApi.md#list_digital_wallet_tokens) | **GET** /cards/digital_wallet_tokens | List Digital Wallet Tokens
*DigitalWalletTokensBetaApi* | [**update_digital_wallet_token_status**](docs/DigitalWalletTokensBetaApi.md#update_digital_wallet_token_status) | **PATCH** /cards/digital_wallet_tokens/{digital_wallet_token_id} | Update Digital Wallet Token&#39;s life cycle status
*ExternalCardsBetaApi* | [**create_external_card_from_token**](docs/ExternalCardsBetaApi.md#create_external_card_from_token) | **POST** /external_cards/tokens | Create External Card from token
*ExternalCardsBetaApi* | [**create_external_card_transfer**](docs/ExternalCardsBetaApi.md#create_external_card_transfer) | **POST** /external_cards/transfers | Create External Card Transfer
*ExternalCardsBetaApi* | [**create_external_card_transfer_reversal**](docs/ExternalCardsBetaApi.md#create_external_card_transfer_reversal) | **POST** /external_cards/transfers/{transfer_id}/reversals | Create External Card Transfer Reversal
*ExternalCardsBetaApi* | [**delete_external_card**](docs/ExternalCardsBetaApi.md#delete_external_card) | **DELETE** /external_cards/{external_card_id} | Delete External Card
*ExternalCardsBetaApi* | [**get_external_card**](docs/ExternalCardsBetaApi.md#get_external_card) | **GET** /external_cards/{external_card_id} | Get External Card
*ExternalCardsBetaApi* | [**get_external_card_transfer**](docs/ExternalCardsBetaApi.md#get_external_card_transfer) | **GET** /external_cards/transfers/{transfer_id} | Get External Card Transfer
*ExternalCardsBetaApi* | [**list_external_card_transfers**](docs/ExternalCardsBetaApi.md#list_external_card_transfers) | **GET** /external_cards/transfers | List External Transfers
*ExternalCardsBetaApi* | [**list_external_cards**](docs/ExternalCardsBetaApi.md#list_external_cards) | **GET** /external_cards | List External Cards
*ExternalCardsBetaApi* | [**update_external_card**](docs/ExternalCardsBetaApi.md#update_external_card) | **PATCH** /external_cards/{external_card_id} | Update External Card
*SpendControlsBetaApi* | [**create_spend_control**](docs/SpendControlsBetaApi.md#create_spend_control) | **POST** /spend_controls | Create Spend Control
*SpendControlsBetaApi* | [**get_spend_control**](docs/SpendControlsBetaApi.md#get_spend_control) | **GET** /spend_controls/{spend_control_id} | Get Spend Control
*SpendControlsBetaApi* | [**list_spend_controls**](docs/SpendControlsBetaApi.md#list_spend_controls) | **GET** /spend_controls | List Spend Controls
*SpendControlsBetaApi* | [**update_spend_control**](docs/SpendControlsBetaApi.md#update_spend_control) | **PATCH** /spend_controls/{spend_control_id} | Update Spend Control
*StatementsApi* | [**get_statement**](docs/StatementsApi.md#get_statement) | **GET** /statements/{statement_id} | Get a statement
*StatementsApi* | [**get_statement_transactions**](docs/StatementsApi.md#get_statement_transactions) | **GET** /statements/{statement_id}/transactions | Get a statement&#39;s transactions
*StatementsApi* | [**list_statements**](docs/StatementsApi.md#list_statements) | **GET** /statements | List statements
*TransactionsBetaApi* | [**get_transaction_by_id**](docs/TransactionsBetaApi.md#get_transaction_by_id) | **GET** /transactions/{id} | Get a transaction by ID
*TransactionsBetaApi* | [**list_transactions**](docs/TransactionsBetaApi.md#list_transactions) | **GET** /transactions | List Transactions
*WebhooksApi* | [**create_webhook**](docs/WebhooksApi.md#create_webhook) | **POST** /webhooks | Create a webhook
*WebhooksApi* | [**delete_webhook**](docs/WebhooksApi.md#delete_webhook) | **DELETE** /webhooks/{webhook_id} | Delete a webhook
*WebhooksApi* | [**get_event**](docs/WebhooksApi.md#get_event) | **GET** /webhooks/{webhook_id}/events/{event_id} | Get webhook event
*WebhooksApi* | [**get_webhook**](docs/WebhooksApi.md#get_webhook) | **GET** /webhooks/{webhook_id} | Get a webhook
*WebhooksApi* | [**list_events**](docs/WebhooksApi.md#list_events) | **GET** /webhooks/{webhook_id}/events | List webhook events
*WebhooksApi* | [**list_webhooks**](docs/WebhooksApi.md#list_webhooks) | **GET** /webhooks | List webhooks
*WebhooksApi* | [**resend_event**](docs/WebhooksApi.md#resend_event) | **POST** /webhooks/{webhook_id}/events/{event_id}/resend | Resend an event
*WebhooksApi* | [**trigger_event**](docs/WebhooksApi.md#trigger_event) | **POST** /webhooks/trigger | Trigger an event
*WebhooksApi* | [**update_webhook**](docs/WebhooksApi.md#update_webhook) | **PUT** /webhooks/{webhook_id} | Update a webhook


## Documentation For Models

 - [AccountSummary](docs/AccountSummary.md)
 - [AccountSummaryBalanceCeiling](docs/AccountSummaryBalanceCeiling.md)
 - [AccountSummaryBalanceFloor](docs/AccountSummaryBalanceFloor.md)
 - [AchTransaction](docs/AchTransaction.md)
 - [AchTransactionAllOf](docs/AchTransactionAllOf.md)
 - [AchTransactionData](docs/AchTransactionData.md)
 - [AchTransactionSubtypes](docs/AchTransactionSubtypes.md)
 - [Address](docs/Address.md)
 - [Address1](docs/Address1.md)
 - [AdverseActionReasonCode](docs/AdverseActionReasonCode.md)
 - [AllApplicationStatus](docs/AllApplicationStatus.md)
 - [AllTransactionSubtypes](docs/AllTransactionSubtypes.md)
 - [AppleDigitalWalletProvisionRequest](docs/AppleDigitalWalletProvisionRequest.md)
 - [AppleDigitalWalletProvisionResponse](docs/AppleDigitalWalletProvisionResponse.md)
 - [Applicant](docs/Applicant.md)
 - [Application](docs/Application.md)
 - [ApplicationList](docs/ApplicationList.md)
 - [ApplicationListAllOf](docs/ApplicationListAllOf.md)
 - [ApplicationPatch](docs/ApplicationPatch.md)
 - [ApplicationResponse](docs/ApplicationResponse.md)
 - [ApplicationType](docs/ApplicationType.md)
 - [AuthRequestModel](docs/AuthRequestModel.md)
 - [AuthorizationAdviceModel](docs/AuthorizationAdviceModel.md)
 - [BalanceInquiryRequestModel](docs/BalanceInquiryRequestModel.md)
 - [BaseCard](docs/BaseCard.md)
 - [BaseCardAllOf](docs/BaseCardAllOf.md)
 - [BaseStatement](docs/BaseStatement.md)
 - [BaseStatementAllOf](docs/BaseStatementAllOf.md)
 - [BaseTransaction](docs/BaseTransaction.md)
 - [BaseTransactionDecline](docs/BaseTransactionDecline.md)
 - [BillingAddress](docs/BillingAddress.md)
 - [Business](docs/Business.md)
 - [CardAcceptorModel](docs/CardAcceptorModel.md)
 - [CardActivationRequest](docs/CardActivationRequest.md)
 - [CardBrand](docs/CardBrand.md)
 - [CardChange](docs/CardChange.md)
 - [CardChangeState](docs/CardChangeState.md)
 - [CardChangesList](docs/CardChangesList.md)
 - [CardChangesListAllOf](docs/CardChangesListAllOf.md)
 - [CardEditRequest](docs/CardEditRequest.md)
 - [CardFormat](docs/CardFormat.md)
 - [CardFulfillmentStatus](docs/CardFulfillmentStatus.md)
 - [CardImageDetails](docs/CardImageDetails.md)
 - [CardImageDetailsList](docs/CardImageDetailsList.md)
 - [CardImageDetailsListAllOf](docs/CardImageDetailsListAllOf.md)
 - [CardImageMode](docs/CardImageMode.md)
 - [CardImageRejectionReason](docs/CardImageRejectionReason.md)
 - [CardImageStatus](docs/CardImageStatus.md)
 - [CardIssuanceRequest](docs/CardIssuanceRequest.md)
 - [CardListResponse](docs/CardListResponse.md)
 - [CardListResponseAllOf](docs/CardListResponseAllOf.md)
 - [CardOptions](docs/CardOptions.md)
 - [CardPinStatus](docs/CardPinStatus.md)
 - [CardProduct](docs/CardProduct.md)
 - [CardProductAllOf](docs/CardProductAllOf.md)
 - [CardProductListResponse](docs/CardProductListResponse.md)
 - [CardProductListResponseAllOf](docs/CardProductListResponseAllOf.md)
 - [CardProductResponse](docs/CardProductResponse.md)
 - [CardProductResponseAllOf](docs/CardProductResponseAllOf.md)
 - [CardResponse](docs/CardResponse.md)
 - [CardStatus](docs/CardStatus.md)
 - [CardStatusObject](docs/CardStatusObject.md)
 - [CardStatusReasonCode](docs/CardStatusReasonCode.md)
 - [CardStatusRequest](docs/CardStatusRequest.md)
 - [CardTransaction](docs/CardTransaction.md)
 - [CardTransactionAllOf](docs/CardTransactionAllOf.md)
 - [CardTransactionData](docs/CardTransactionData.md)
 - [CardTransactionDataCurrencyConversion](docs/CardTransactionDataCurrencyConversion.md)
 - [CardTransactionDataMerchant](docs/CardTransactionDataMerchant.md)
 - [CardTransactionDataPos](docs/CardTransactionDataPos.md)
 - [CardTransactionSubtypes](docs/CardTransactionSubtypes.md)
 - [CardType](docs/CardType.md)
 - [CardWidgetUrlResponse](docs/CardWidgetUrlResponse.md)
 - [CashTransaction](docs/CashTransaction.md)
 - [CashTransactionAllOf](docs/CashTransactionAllOf.md)
 - [CashTransactionData](docs/CashTransactionData.md)
 - [CashTransactionSubtypes](docs/CashTransactionSubtypes.md)
 - [ChangeChannel](docs/ChangeChannel.md)
 - [ChangeType](docs/ChangeType.md)
 - [ChargeSecuredStatement](docs/ChargeSecuredStatement.md)
 - [ChargeSecuredStatementAllOf](docs/ChargeSecuredStatementAllOf.md)
 - [CheckTransaction](docs/CheckTransaction.md)
 - [CheckTransactionAllOf](docs/CheckTransactionAllOf.md)
 - [CheckTransactionData](docs/CheckTransactionData.md)
 - [CheckTransactionSubtypes](docs/CheckTransactionSubtypes.md)
 - [ClearingModel](docs/ClearingModel.md)
 - [ClientToken](docs/ClientToken.md)
 - [CreateCardImageRequest](docs/CreateCardImageRequest.md)
 - [CreateGatewayRequest](docs/CreateGatewayRequest.md)
 - [CreateTransferResponse](docs/CreateTransferResponse.md)
 - [CreateTransferResponsePull](docs/CreateTransferResponsePull.md)
 - [CreateTransferResponsePullAllOf](docs/CreateTransferResponsePullAllOf.md)
 - [CreateTransferResponsePush](docs/CreateTransferResponsePush.md)
 - [CreateTransferResponsePushAllOf](docs/CreateTransferResponsePushAllOf.md)
 - [CreateTransferType](docs/CreateTransferType.md)
 - [CreditApplication](docs/CreditApplication.md)
 - [CreditApplicationPatch](docs/CreditApplicationPatch.md)
 - [CreditApplicationResponse](docs/CreditApplicationResponse.md)
 - [CreditApplicationResponseAllOf](docs/CreditApplicationResponseAllOf.md)
 - [CreditApplicationStatus](docs/CreditApplicationStatus.md)
 - [CreditCard](docs/CreditCard.md)
 - [CreditCardRequestDetails](docs/CreditCardRequestDetails.md)
 - [CreditCardResponse](docs/CreditCardResponse.md)
 - [CreditCardResponseDetails](docs/CreditCardResponseDetails.md)
 - [CreditScore](docs/CreditScore.md)
 - [CreditSummary](docs/CreditSummary.md)
 - [CustomerServiceDetails](docs/CustomerServiceDetails.md)
 - [DcSign](docs/DcSign.md)
 - [DebitCard](docs/DebitCard.md)
 - [DebitCardRequestDetails](docs/DebitCardRequestDetails.md)
 - [DebitCardResponse](docs/DebitCardResponse.md)
 - [DebitCardResponseDetails](docs/DebitCardResponseDetails.md)
 - [DeclineInfo](docs/DeclineInfo.md)
 - [DeleteResponse](docs/DeleteResponse.md)
 - [DepositoryStatement](docs/DepositoryStatement.md)
 - [DepositoryStatementAllOf](docs/DepositoryStatementAllOf.md)
 - [DeviceType](docs/DeviceType.md)
 - [DigitalWalletTokenAddressVerification](docs/DigitalWalletTokenAddressVerification.md)
 - [DigitalWalletTokenEditRequest](docs/DigitalWalletTokenEditRequest.md)
 - [DigitalWalletTokenResponse](docs/DigitalWalletTokenResponse.md)
 - [DigitalWalletTokenState](docs/DigitalWalletTokenState.md)
 - [DigitalWalletTokenization](docs/DigitalWalletTokenization.md)
 - [EmbossName](docs/EmbossName.md)
 - [EnhancedRawDetails](docs/EnhancedRawDetails.md)
 - [EnhancedTransactionData](docs/EnhancedTransactionData.md)
 - [EnhancedTransactionData1](docs/EnhancedTransactionData1.md)
 - [EnhancedTransactionData1EnhancedRawInner](docs/EnhancedTransactionData1EnhancedRawInner.md)
 - [Error](docs/Error.md)
 - [Event](docs/Event.md)
 - [EventList](docs/EventList.md)
 - [EventListAllOf](docs/EventListAllOf.md)
 - [EventListEvent](docs/EventListEvent.md)
 - [EventTrigger](docs/EventTrigger.md)
 - [EventType](docs/EventType.md)
 - [EventTypeExplicit](docs/EventTypeExplicit.md)
 - [EventTypeWildcard](docs/EventTypeWildcard.md)
 - [ExternalCardListResponse](docs/ExternalCardListResponse.md)
 - [ExternalCardListResponseAllOf](docs/ExternalCardListResponseAllOf.md)
 - [ExternalCardRequest](docs/ExternalCardRequest.md)
 - [ExternalCardResponse](docs/ExternalCardResponse.md)
 - [ExternalCardStatus](docs/ExternalCardStatus.md)
 - [ExternalCardTransaction](docs/ExternalCardTransaction.md)
 - [ExternalCardTransactionAllOf](docs/ExternalCardTransactionAllOf.md)
 - [ExternalCardTransactionSubtypes](docs/ExternalCardTransactionSubtypes.md)
 - [ExternalCardUpdateRequest](docs/ExternalCardUpdateRequest.md)
 - [ExternalCardVerifications](docs/ExternalCardVerifications.md)
 - [FinancialInstitution](docs/FinancialInstitution.md)
 - [FinancialRequestModel](docs/FinancialRequestModel.md)
 - [FinancialStatus](docs/FinancialStatus.md)
 - [Form](docs/Form.md)
 - [FraudRiskData](docs/FraudRiskData.md)
 - [FulfillmentDetails](docs/FulfillmentDetails.md)
 - [GatewayListResponse](docs/GatewayListResponse.md)
 - [GatewayListResponseAllOf](docs/GatewayListResponseAllOf.md)
 - [GatewayResponse](docs/GatewayResponse.md)
 - [GatewayStandin](docs/GatewayStandin.md)
 - [GetCardBarcode200Response](docs/GetCardBarcode200Response.md)
 - [GoogleDigitalWalletProvisionRequest](docs/GoogleDigitalWalletProvisionRequest.md)
 - [GoogleDigitalWalletProvisionResponse](docs/GoogleDigitalWalletProvisionResponse.md)
 - [InAppProvisioning](docs/InAppProvisioning.md)
 - [Income](docs/Income.md)
 - [IncomeBase](docs/IncomeBase.md)
 - [IncomeBaseFrequency](docs/IncomeBaseFrequency.md)
 - [IncomeBaseWithoutOtherDetails](docs/IncomeBaseWithoutOtherDetails.md)
 - [IncomeType](docs/IncomeType.md)
 - [IncomeTypeWithOtherDetails](docs/IncomeTypeWithOtherDetails.md)
 - [IncomeTypeWithOtherDetailsAllOf](docs/IncomeTypeWithOtherDetailsAllOf.md)
 - [InternalTransferTransaction](docs/InternalTransferTransaction.md)
 - [InternalTransferTransactionAllOf](docs/InternalTransferTransactionAllOf.md)
 - [InternalTransferTransactionData](docs/InternalTransferTransactionData.md)
 - [InternalTransferTransactionSubtypes](docs/InternalTransferTransactionSubtypes.md)
 - [LineOfCreditStatement](docs/LineOfCreditStatement.md)
 - [LineOfCreditStatementAllOf](docs/LineOfCreditStatementAllOf.md)
 - [ManualEntry](docs/ManualEntry.md)
 - [Merchant](docs/Merchant.md)
 - [NetworkFeeModel](docs/NetworkFeeModel.md)
 - [OriginalCreditRequestModel](docs/OriginalCreditRequestModel.md)
 - [OriginalCreditSenderData](docs/OriginalCreditSenderData.md)
 - [PaginatedResponse](docs/PaginatedResponse.md)
 - [PaginatedTransactions](docs/PaginatedTransactions.md)
 - [PaymentSubType](docs/PaymentSubType.md)
 - [PaymentType](docs/PaymentType.md)
 - [Person](docs/Person.md)
 - [PhysicalCard](docs/PhysicalCard.md)
 - [PhysicalCardAllOf](docs/PhysicalCardAllOf.md)
 - [PhysicalCardFormat](docs/PhysicalCardFormat.md)
 - [PhysicalCardPlusStatus](docs/PhysicalCardPlusStatus.md)
 - [PhysicalCreditCardIssuanceRequest](docs/PhysicalCreditCardIssuanceRequest.md)
 - [PhysicalCreditCardResponse](docs/PhysicalCreditCardResponse.md)
 - [PhysicalCreditCardResponseAllOf](docs/PhysicalCreditCardResponseAllOf.md)
 - [PhysicalDebitCardIssuanceRequest](docs/PhysicalDebitCardIssuanceRequest.md)
 - [PhysicalDebitCardResponse](docs/PhysicalDebitCardResponse.md)
 - [PhysicalDebitCardResponseStatus](docs/PhysicalDebitCardResponseStatus.md)
 - [PhysicalDebitCardResponseStatusAllOf](docs/PhysicalDebitCardResponseStatusAllOf.md)
 - [ProvisioningControls](docs/ProvisioningControls.md)
 - [PushTokenizeRequestData](docs/PushTokenizeRequestData.md)
 - [RecipientName](docs/RecipientName.md)
 - [ResponseHistoryItem](docs/ResponseHistoryItem.md)
 - [RestrictedApplication](docs/RestrictedApplication.md)
 - [RestrictedApplicationDetails](docs/RestrictedApplicationDetails.md)
 - [RestrictedApplicationDocument](docs/RestrictedApplicationDocument.md)
 - [RestrictedApplicationItem](docs/RestrictedApplicationItem.md)
 - [RestrictedApplicationItemType](docs/RestrictedApplicationItemType.md)
 - [RestrictedApplicationPage](docs/RestrictedApplicationPage.md)
 - [RestrictedApplicationPatch](docs/RestrictedApplicationPatch.md)
 - [RestrictedApplicationQuestion](docs/RestrictedApplicationQuestion.md)
 - [RestrictedApplicationResponse](docs/RestrictedApplicationResponse.md)
 - [RestrictedApplicationResponseAllOf](docs/RestrictedApplicationResponseAllOf.md)
 - [RestrictedApplicationSection](docs/RestrictedApplicationSection.md)
 - [RestrictedApplicationStatus](docs/RestrictedApplicationStatus.md)
 - [ReversalModel](docs/ReversalModel.md)
 - [ReviewDetails](docs/ReviewDetails.md)
 - [SavingSummary](docs/SavingSummary.md)
 - [SecurityAccountSummary](docs/SecurityAccountSummary.md)
 - [Shipping](docs/Shipping.md)
 - [ShippingAddress](docs/ShippingAddress.md)
 - [SimulateCardFulfillment](docs/SimulateCardFulfillment.md)
 - [SpendControl](docs/SpendControl.md)
 - [SpendControlCreationRequest](docs/SpendControlCreationRequest.md)
 - [SpendControlDirection](docs/SpendControlDirection.md)
 - [SpendControlResponse](docs/SpendControlResponse.md)
 - [SpendControlResponseAllOf](docs/SpendControlResponseAllOf.md)
 - [SpendControlResponseList](docs/SpendControlResponseList.md)
 - [SpendControlResponseListAllOf](docs/SpendControlResponseListAllOf.md)
 - [SpendControlRollingWindowDays](docs/SpendControlRollingWindowDays.md)
 - [SpendControlRollingWindowDaysAllOf](docs/SpendControlRollingWindowDaysAllOf.md)
 - [SpendControlSingleTransaction](docs/SpendControlSingleTransaction.md)
 - [SpendControlTimeRange](docs/SpendControlTimeRange.md)
 - [SpendControlTimeRangeType](docs/SpendControlTimeRangeType.md)
 - [SpendControlUpdateRequest](docs/SpendControlUpdateRequest.md)
 - [Statement](docs/Statement.md)
 - [StatementList](docs/StatementList.md)
 - [StatementListAllOf](docs/StatementListAllOf.md)
 - [StatementSummary](docs/StatementSummary.md)
 - [StatementType](docs/StatementType.md)
 - [ThreeDsPolicy](docs/ThreeDsPolicy.md)
 - [TokenList](docs/TokenList.md)
 - [TokenListResponse](docs/TokenListResponse.md)
 - [Transaction](docs/Transaction.md)
 - [Transaction1](docs/Transaction1.md)
 - [TransactionDataV0](docs/TransactionDataV0.md)
 - [TransactionLineV0](docs/TransactionLineV0.md)
 - [TransactionList](docs/TransactionList.md)
 - [TransactionListAllOf](docs/TransactionListAllOf.md)
 - [TransactionOptions](docs/TransactionOptions.md)
 - [TransactionStatuses](docs/TransactionStatuses.md)
 - [TransactionTypes](docs/TransactionTypes.md)
 - [TransactionV0](docs/TransactionV0.md)
 - [TransferListResponse](docs/TransferListResponse.md)
 - [TransferListResponseAllOf](docs/TransferListResponseAllOf.md)
 - [TransferRequest](docs/TransferRequest.md)
 - [TransferRequestBase](docs/TransferRequestBase.md)
 - [TransferRequestPull](docs/TransferRequestPull.md)
 - [TransferRequestPullAllOf](docs/TransferRequestPullAllOf.md)
 - [TransferRequestPush](docs/TransferRequestPush.md)
 - [TransferRequestPushAllOf](docs/TransferRequestPushAllOf.md)
 - [TransferResponse](docs/TransferResponse.md)
 - [TransferResponseBase](docs/TransferResponseBase.md)
 - [TransferResponsePull](docs/TransferResponsePull.md)
 - [TransferResponsePullAllOf](docs/TransferResponsePullAllOf.md)
 - [TransferResponsePush](docs/TransferResponsePush.md)
 - [TransferResponsePushAllOf](docs/TransferResponsePushAllOf.md)
 - [TransferReversalRequest](docs/TransferReversalRequest.md)
 - [TransferType](docs/TransferType.md)
 - [TransferTypeRequest](docs/TransferTypeRequest.md)
 - [TriggerEventRequest](docs/TriggerEventRequest.md)
 - [TxnEnhancer](docs/TxnEnhancer.md)
 - [UpdateCardImageRequest](docs/UpdateCardImageRequest.md)
 - [UpdateGatewayRequest](docs/UpdateGatewayRequest.md)
 - [VirtualCard](docs/VirtualCard.md)
 - [VirtualCardPlusStatus](docs/VirtualCardPlusStatus.md)
 - [VirtualCreditCardIssuanceRequest](docs/VirtualCreditCardIssuanceRequest.md)
 - [VirtualCreditCardResponse](docs/VirtualCreditCardResponse.md)
 - [VirtualCreditCardResponseAllOf](docs/VirtualCreditCardResponseAllOf.md)
 - [VirtualDebitCardIssuanceRequest](docs/VirtualDebitCardIssuanceRequest.md)
 - [VirtualDebitCardResponse](docs/VirtualDebitCardResponse.md)
 - [VirtualDebitCardResponseStatus](docs/VirtualDebitCardResponseStatus.md)
 - [WalletProviderCardOnFile](docs/WalletProviderCardOnFile.md)
 - [Webhook](docs/Webhook.md)
 - [WebhookList](docs/WebhookList.md)
 - [WebhookListAllOf](docs/WebhookListAllOf.md)
 - [WebhookRequestObject](docs/WebhookRequestObject.md)
 - [WidgetType](docs/WidgetType.md)
 - [WireTransaction](docs/WireTransaction.md)
 - [WireTransactionAllOf](docs/WireTransactionAllOf.md)
 - [WireTransactionData](docs/WireTransactionData.md)
 - [WireTransactionSubtypes](docs/WireTransactionSubtypes.md)
 - [WithdrawalRequestModel](docs/WithdrawalRequestModel.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (api_key)


## Author

dev@swadesh.co


